@@ -2,9 +2,9 @@ import logging
 from argparse import Namespace
 from abc import ABC, abstractmethod
 
-from src.Argument import Argument
-from src.adaptors.InputAdaptorHandler import InputAdaptorHandler
-from src.adaptors.OutputAdaptorHandler import OutputAdaptorHandler
+from .Argument import Argument
+from .adaptors.InputAdaptorHandler import InputAdaptorHandler
+from .adaptors.OutputAdaptorHandler import OutputAdaptorHandler
 
 class AbstractAction(ABC):
   name:str
