@@ -1,9 +1,9 @@
 import logging
 from argparse import Namespace
 
-from src.Argument import Argument
+from .Argument import Argument
 from .AbstractAction import AbstractAction
-from src.ConfigurationHandler import ConfigurationHandler
+from .ConfigurationHandler import ConfigurationHandler
 
 
 class AbstractActionWithConfiguration(AbstractAction):
