@@ -1,7 +1,7 @@
 from os import path
 
-from src.adaptors.input.InputJSONFileAdaptor import InputJSONFileAdaptor
-from src.adaptors.output.OutputJSONFileAdaptor import OutputJSONFileAdaptor
+from .adaptors.input.InputJSONFileAdaptor import InputJSONFileAdaptor
+from .adaptors.output.OutputJSONFileAdaptor import OutputJSONFileAdaptor
 
 FILE_PATH = path.abspath(path.join(path.dirname(__file__), '../conf.json'))
 
